@@ -12,7 +12,7 @@ do
 	obj=`echo $src | sed "s/\.c\$/.o/"`
 	libobj="$libobj $obj"
 	echo	"$obj : $src"
-	echo	'	$(CC) $(CC_FLAGS) -c '"$src"
+	echo	'	$(CC) $(CC_ONLY) $(CC_FLAGS) -c '"$src"
 	echo
 	echo	"clean ::"
 	echo	"	rm -f $obj"
