@@ -455,14 +455,14 @@ int msqlConnect(host)
 	}
 	else
 	{
-	        tcpPort = ntohs(MSQL_PORT);
+	        tcpPort = MSQL_PORT;
         	if ((serv_ptr = getservbyname("msql", "tcp")))
         	{
                 	tcpPort = ntohs(serv_ptr->s_port);
         	}
         	if ((envVar = getenv("MSQL_TCP_PORT")))
         	{
-                	tcpPort = ntohs(atoi(envVar));
+                	tcpPort = atoi(envVar);
         	}
 
 		sprintf(hostInfo,"%s via TCP/IP",host);
