@@ -437,9 +437,24 @@ int msqlAddField(ident,type,length,notNull,priKey)
 	new = (field_t *)malloc(sizeof(field_t));
 	if (table)
 	{
-		(void)strncpy(new->table,table,NAME_LEN - 1);
+		if (strlen(table) > NAME_LEN)
+		{
+			sprintf(packet, "-1:Table name '%s' is too long\n",
+				table);
+			writePkt(outSock);
+			msqlTrace(TRACE_OUT,"msqlAddField()");
+			return(-1);
+		}
+		(void)strcpy(new->table,table);
 	}
-	(void)strncpy(new->name,name,NAME_LEN - 1);
+	if (strlen(name) > NAME_LEN)
+	{
+		sprintf(packet, "-1:Field name '%s' is too long\n", name);
+		writePkt(outSock);
+		msqlTrace(TRACE_OUT,"msqlAddField()");
+		return(-1);
+	}
+	(void)strcpy(new->name,name);
 	if (notNull)
 	{
 		new->flags |= NOT_NULL_FLAG;
@@ -537,7 +552,7 @@ msqlAddFieldValue(value)
 **		  element of a where_clause.
 */
 
-msqlAddCond(ident,op,value,bool)
+int msqlAddCond(ident,op,value,bool)
 	ident_t	*ident;
 	int	op;
 	val_t	*value;
@@ -560,6 +575,25 @@ msqlAddCond(ident,op,value,bool)
 		table = NULL;
 	}
 
+	if (strlen(name) > NAME_LEN)
+	{
+		sprintf(packet, "-1:Field name '%s' is too long\n", 
+			name);
+		writePkt(outSock);
+		msqlTrace(TRACE_OUT,"msqlAddCond()");
+		return(-1);
+	}
+	if (table)
+	{
+		if (strlen(table) > NAME_LEN)
+		{
+			sprintf(packet, "-1:Table name '%s' is too long\n", 
+				name);
+			writePkt(outSock);
+			msqlTrace(TRACE_OUT,"msqlAddCond()");
+			return(-1);
+		}
+	}
 	new = (cond_t *)malloc(sizeof(cond_t));
 	(void)strcpy(new->name,name);
 	if (table)
@@ -582,6 +616,7 @@ msqlAddCond(ident,op,value,bool)
 	}
 	free(ident);
 	msqlTrace(TRACE_OUT,"msqlAddCond()");
+	return(0);
 }
 
 
@@ -626,22 +661,86 @@ msqlAddOrder(ident,dir)
 
 
 
-msqlAddTable(name,alias)
+int msqlAddTable(name,alias)
 	char	*name,
 		*alias;
 {
-	register tname_t	*new;
+	register tname_t	*new,
+				*cur;
 
 	msqlTrace(TRACE_IN,"msqlAddTable()");
 
 	new = (tname_t *)malloc(sizeof(tname_t));
 	if (alias)
 	{
+		/*
+		** Ensure the alias is unique
+		*/
+		cur = tableHead;
+		while(cur)
+		{
+			if (strcmp(cur->name,alias) == 0)
+			{
+				sprintf(packet, 
+					"-1:Nonunique table/alias name '%s'\n", 
+					alias);
+				writePkt(outSock);
+				msqlTrace(TRACE_OUT,"msqlAddTable()");
+				return(-1);
+			}
+			cur = cur->next;
+		}
+
+		/*
+		** Further checks on the table/alias name
+		*/
+		if (strlen(name) > NAME_LEN)
+		{
+			sprintf(packet, "-1:Table name '%s' is too long\n", 
+				name);
+			writePkt(outSock);
+			msqlTrace(TRACE_OUT,"msqlAddTable()");
+			return(-1);
+		}
+		if (strlen(alias) > NAME_LEN)
+		{
+			sprintf(packet,"-1:Table alias name '%s' is too long\n",
+				name);
+			writePkt(outSock);
+			msqlTrace(TRACE_OUT,"msqlAddTable()");
+			return(-1);
+		}
 		(void)strcpy(new->name,alias);
 		(void)strcpy(new->cname,name);
 	}
 	else
 	{
+		/*
+		** Ensure the table is unique
+		*/
+		cur = tableHead;
+		while(cur)
+		{
+			if (strcmp(cur->name,name) == 0)
+			{
+				sprintf(packet, 
+					"-1:Nonunique table name '%s'\n", 
+					name);
+				writePkt(outSock);
+				msqlTrace(TRACE_OUT,"msqlAddTable()");
+				return(-1);
+			}
+			cur = cur->next;
+		}
+
+		if (strlen(name) > NAME_LEN)
+		{
+			sprintf(packet, "-1:Table name '%s' is too long\n", 
+				name);
+			writePkt(outSock);
+			msqlTrace(TRACE_OUT,"msqlAddTable()");
+			return(-1);
+		}
 		(void)strcpy(new->name,name);
 		*(new->cname) = 0;
 	}
@@ -655,6 +754,7 @@ msqlAddTable(name,alias)
 		tableTail = new;
 	}
 	msqlTrace(TRACE_OUT,"msqlAddTable()");
+	return(0);
 }
 
 
