@@ -40,10 +40,19 @@
 #define EX_CONSCHECK 3
 
 char	usage[] = "\n\n\
-usage: 	%s [-h host] [-v] database [table]\n\n\
-	Produce an ASCII dump of a database table or an entire database\n\n";
+usage: 	%s [-h host] [-vtdc] database [table]\n\n\
+	Produce an ASCII dump of a database table or an entire database\n\n\
+	-h	Use mSQL server on remote host\n\
+	-v	Verbose mode\n\
+	-t	Do not produce the table creation information\n\
+	-d	Do not produce the data insertion information\n\
+	-c	Complete INSERT statements (including field names)\n\
+\n";
 
-int	verbose = 0;
+int	verbose = 0,
+	tFlag = 0,
+	cFlag = 0,
+	dFlag = 0;
 int	sock = -1;
 char	insert_pat[5 * 1024];
 
@@ -77,6 +86,13 @@ char *escapeText(str)
 		numQuotes++;
 		cp++;
 	}
+	cp = str;
+	while((cp = (char *)index(cp,'\\')))
+	{
+		numQuotes++;
+		cp++;
+	}
+
 	if (numQuotes)
 	{
 		tmp = (char *)malloc(strlen(str)+numQuotes+1);
@@ -84,7 +100,7 @@ char *escapeText(str)
 		cp = str;
 		while(*cp)
 		{
-			if (*cp == '\'')
+			if (*cp == '\'' || *cp == '\\')
 				*cp2++='\\';
 			*cp2++ = *cp++;
 		}
@@ -164,9 +180,16 @@ int getTableStructure(table)
 		exit(EX_MSQLERR);
 	}
 
-	printf("\n#\n# Table structure for table '%s'\n#\n",table);
-	sprintf(insert_pat, "INSERT INTO %s VALUES (", table);
-	printf("CREATE TABLE %s (\n", table);
+	if (!tFlag)
+	{
+		printf("\n#\n# Table structure for table '%s'\n#\n",table);
+		printf("CREATE TABLE %s (\n", table);
+	}
+
+	if (cFlag)
+		sprintf(insert_pat, "INSERT INTO %s (", table);
+	else
+		sprintf(insert_pat, "INSERT INTO %s VALUES (", table);
 
 	while(mf=msqlFetchField(tableRes)) 
 	{
@@ -176,32 +199,44 @@ int getTableStructure(table)
 		}
 		else
 		{
-			printf(",\n");
+			if (!tFlag)
+				printf(",\n");
+			if (cFlag)
+				strcat(insert_pat,", ");
 		}
-		printf("  %s ", mf->name);
-		switch(mf->type) 
+		if (cFlag)
+			strcat(insert_pat,mf->name);
+		if (!tFlag)
 		{
-			case INT_TYPE:
-				printf("INT");
-				break;
-			case CHAR_TYPE:
-				printf("CHAR(%d)", mf->length);
-				break;
-			case REAL_TYPE:
-				printf("REAL");
-				break;
-			default:
-				fprintf(stderr, "Unknown field type: %d\n", 
-					mf->type);
-				exit(EX_CONSCHECK);
-		}
+			printf("  %s ", mf->name);
+			switch(mf->type) 
+			{
+				case INT_TYPE:
+					printf("INT");
+					break;
+				case CHAR_TYPE:
+					printf("CHAR(%d)", mf->length);
+					break;
+				case REAL_TYPE:
+					printf("REAL");
+					break;
+				default:
+					fprintf(stderr, 
+						"Unknown field type: %d\n", 
+						mf->type);
+					exit(EX_CONSCHECK);
+			}
 
-		if(IS_NOT_NULL(mf->flags) )
-			printf(" NOT NULL");
-		if(IS_PRI_KEY(mf->flags) )
-			printf(" PRIMARY KEY");
+			if(IS_NOT_NULL(mf->flags) )
+				printf(" NOT NULL");
+			if(IS_PRI_KEY(mf->flags) )
+				printf(" PRIMARY KEY");
+		}
 	}
-	printf("\n) \\g\n\n");
+	if (!tFlag)
+		printf("\n) \\g\n\n");
+	if (cFlag)
+		strcat(insert_pat,") VALUES (");
 	numFields = msqlNumFields(tableRes);
 	msqlFreeResult(tableRes);
 	return(numFields);
@@ -327,7 +362,7 @@ main(argc, argv)
 	/*
 	** Check out the args
 	*/
-	while((c=getopt(argc,argv,"h:v"))!= -1)
+	while((c=getopt(argc,argv,"h:vtcd"))!= -1)
 	{
 		switch(c)
 		{
@@ -345,6 +380,27 @@ main(argc, argv)
 					verbose++;
 				break;
 
+			case 't':
+				if (tFlag)
+					errFlag++;
+				else
+					tFlag++;
+				break;
+
+			case 'c':
+				if (cFlag)
+					errFlag++;
+				else
+					cFlag++;
+				break;
+
+			case 'd':
+				if (dFlag)
+					errFlag++;
+				else
+					dFlag++;
+				break;
+
 			case '?':
 				errFlag++;
 		}
@@ -375,18 +431,21 @@ main(argc, argv)
 	if (table)
 	{
 		numRows = getTableStructure(table);
-		dumpTable(numRows,table);
+		if (!dFlag)
+			dumpTable(numRows,table);
 	}
 	else
 	{
 		while((table = getTableName()))
 		{
 			numRows = getTableStructure(table);
-			dumpTable(numRows,table);
+			if (!dFlag)
+				dumpTable(numRows,table);
 		}
 	}
 	dbDisconnect(host);
 	printf("\n");
+	exit(0);
 }
 
 
