@@ -193,7 +193,7 @@ main(argc,argv)
 		res = msqlListFields(sock,argv[optind+1]);
 		if (!res)
 		{
-			printf("ERROR : Couldn't find %s in %s!\n\n",
+			printf("\nERROR : Couldn't find table '%s' in '%s'\n\n",
 				argv[optind+1], argv[optind]);
 			exit(1);
 		}
